@@ -8,9 +8,8 @@
  * file that was distributed with this source code.
  */
 
-/**
- * @since Class available since Release 4.0.0
- */
-class PHPUnit_Framework_CodeCoverageException extends PHPUnit_Framework_Exception
+namespace PHPUnit\Framework;
+
+class CodeCoverageException extends Exception
 {
 }
