@@ -7,13 +7,12 @@
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
+namespace PHPUnit\Framework\Constraint;
 
 /**
  * Constraint that accepts finite.
- *
- * @since      Class available since Release 5.0.0
  */
-class PHPUnit_Framework_Constraint_IsFinite extends PHPUnit_Framework_Constraint
+class IsFinite extends Constraint
 {
     /**
      * Evaluates the constraint for parameter $other. Returns true if the
@@ -25,7 +24,7 @@ class PHPUnit_Framework_Constraint_IsFinite extends PHPUnit_Framework_Constraint
      */
     protected function matches($other)
     {
-        return is_finite($other);
+        return \is_finite($other);
     }
 
     /**
