@@ -7,16 +7,15 @@
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
+namespace PHPUnit\Framework\Constraint;
 
 /**
  * Constraint that asserts that the value it is evaluated for is of a
  * specified type.
  *
  * The expected value is passed in the constructor.
- *
- * @since Class available since Release 3.0.0
  */
-class PHPUnit_Framework_Constraint_IsType extends PHPUnit_Framework_Constraint
+class IsType extends Constraint
 {
     const TYPE_ARRAY    = 'array';
     const TYPE_BOOL     = 'bool';
@@ -33,23 +32,23 @@ class PHPUnit_Framework_Constraint_IsType extends PHPUnit_Framework_Constraint
     /**
      * @var array
      */
-    protected $types = array(
-      'array'    => true,
-      'boolean'  => true,
-      'bool'     => true,
-      'double'   => true,
-      'float'    => true,
-      'integer'  => true,
-      'int'      => true,
-      'null'     => true,
-      'numeric'  => true,
-      'object'   => true,
-      'real'     => true,
-      'resource' => true,
-      'string'   => true,
-      'scalar'   => true,
-      'callable' => true
-    );
+    protected $types = [
+        'array'    => true,
+        'boolean'  => true,
+        'bool'     => true,
+        'double'   => true,
+        'float'    => true,
+        'integer'  => true,
+        'int'      => true,
+        'null'     => true,
+        'numeric'  => true,
+        'object'   => true,
+        'real'     => true,
+        'resource' => true,
+        'string'   => true,
+        'scalar'   => true,
+        'callable' => true
+    ];
 
     /**
      * @var string
@@ -57,17 +56,18 @@ class PHPUnit_Framework_Constraint_IsType extends PHPUnit_Framework_Constraint
     protected $type;
 
     /**
-     * @param  string                      $type
-     * @throws PHPUnit_Framework_Exception
+     * @param string $type
+     *
+     * @throws \PHPUnit\Framework\Exception
      */
     public function __construct($type)
     {
         parent::__construct();
 
         if (!isset($this->types[$type])) {
-            throw new PHPUnit_Framework_Exception(
-                sprintf(
-                    'Type specified for PHPUnit_Framework_Constraint_IsType <%s> ' .
+            throw new \PHPUnit\Framework\Exception(
+                \sprintf(
+                    'Type specified for PHPUnit\Framework\Constraint\IsType <%s> ' .
                     'is not a valid type.',
                     $type
                 )
@@ -81,48 +81,49 @@ class PHPUnit_Framework_Constraint_IsType extends PHPUnit_Framework_Constraint
      * Evaluates the constraint for parameter $other. Returns true if the
      * constraint is met, false otherwise.
      *
-     * @param  mixed $other Value or object to evaluate.
+     * @param mixed $other Value or object to evaluate.
+     *
      * @return bool
      */
     protected function matches($other)
     {
         switch ($this->type) {
             case 'numeric':
-                return is_numeric($other);
+                return \is_numeric($other);
 
             case 'integer':
             case 'int':
-                return is_integer($other);
+                return \is_int($other);
 
             case 'double':
             case 'float':
             case 'real':
-                return is_float($other);
+                return \is_float($other);
 
             case 'string':
-                return is_string($other);
+                return \is_string($other);
 
             case 'boolean':
             case 'bool':
-                return is_bool($other);
+                return \is_bool($other);
 
             case 'null':
-                return is_null($other);
+                return null === $other;
 
             case 'array':
-                return is_array($other);
+                return \is_array($other);
 
             case 'object':
-                return is_object($other);
+                return \is_object($other);
 
             case 'resource':
-                return is_resource($other) || is_string(@get_resource_type($other));
+                return \is_resource($other) || \is_string(@\get_resource_type($other));
 
             case 'scalar':
-                return is_scalar($other);
+                return \is_scalar($other);
 
             case 'callable':
-                return is_callable($other);
+                return \is_callable($other);
         }
     }
 
@@ -133,7 +134,7 @@ class PHPUnit_Framework_Constraint_IsType extends PHPUnit_Framework_Constraint
      */
     public function toString()
     {
-        return sprintf(
+        return \sprintf(
             'is of type "%s"',
             $this->type
         );
