@@ -7,13 +7,12 @@
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
+namespace PHPUnit\Framework;
 
 /**
  * A warning.
- *
- * @since Class available since Release 2.0.0
  */
-class PHPUnit_Framework_WarningTestCase extends PHPUnit_Framework_TestCase
+class WarningTestCase extends TestCase
 {
     /**
      * @var string
@@ -50,17 +49,15 @@ class PHPUnit_Framework_WarningTestCase extends PHPUnit_Framework_TestCase
     }
 
     /**
-     * @throws PHPUnit_Framework_Exception
+     * @throws Exception
      */
     protected function runTest()
     {
-        throw new PHPUnit_Framework_Warning($this->message);
+        throw new Warning($this->message);
     }
 
     /**
      * @return string
-     *
-     * @since  Method available since Release 3.0.0
      */
     public function getMessage()
     {
@@ -71,8 +68,6 @@ class PHPUnit_Framework_WarningTestCase extends PHPUnit_Framework_TestCase
      * Returns a string representation of the test case.
      *
      * @return string
-     *
-     * @since  Method available since Release 3.4.0
      */
     public function toString()
     {
