@@ -8,12 +8,14 @@
  * file that was distributed with this source code.
  */
 
+namespace PHPUnit\Runner;
+
+use ReflectionClass;
+
 /**
  * An interface to define how a test suite should be loaded.
- *
- * @since      Interface available since Release 2.0.0
  */
-interface PHPUnit_Runner_TestSuiteLoader
+interface TestSuiteLoader
 {
     /**
      * @param string $suiteClassName
