@@ -7,6 +7,14 @@
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
+namespace PHPUnit\Util;
+
+use DOMElement;
+use DOMXPath;
+use File_Iterator_Facade;
+use PHPUnit\Framework\Exception;
+use PHPUnit\Framework\TestSuite;
+use PHPUnit\TextUI\ResultPrinter;
 
 /**
  * Wrapper for the PHPUnit XML configuration file.
@@ -15,18 +23,18 @@
  * <code>
  * <?xml version="1.0" encoding="utf-8" ?>
  *
- * <phpunit backupGlobals="true"
+ * <phpunit backupGlobals="false"
  *          backupStaticAttributes="false"
  *          bootstrap="/path/to/bootstrap.php"
  *          cacheTokens="false"
  *          columns="80"
  *          colors="false"
  *          stderr="false"
+ *          convertDeprecationsToExceptions="true"
  *          convertErrorsToExceptions="true"
  *          convertNoticesToExceptions="true"
  *          convertWarningsToExceptions="true"
  *          forceCoversAnnotation="false"
- *          printerClass="PHPUnit_TextUI_ResultPrinter"
  *          processIsolation="false"
  *          stopOnError="false"
  *          stopOnFailure="false"
@@ -36,15 +44,18 @@
  *          stopOnSkipped="false"
  *          failOnWarning="false"
  *          failOnRisky="false"
- *          testSuiteLoaderClass="PHPUnit_Runner_StandardTestSuiteLoader"
+ *          extensionsDirectory="tools/phpunit.d"
+ *          printerClass="PHPUnit\TextUI\ResultPrinter"
+ *          testSuiteLoaderClass="PHPUnit\Runner\StandardTestSuiteLoader"
+ *          defaultTestSuite=""
  *          beStrictAboutChangesToGlobalState="false"
  *          beStrictAboutCoversAnnotation="false"
  *          beStrictAboutOutputDuringTests="false"
  *          beStrictAboutResourceUsageDuringSmallTests="false"
  *          beStrictAboutTestsThatDoNotTestAnything="false"
  *          beStrictAboutTodoAnnotatedTests="false"
- *          checkForUnintentionallyCoveredCode="false"
  *          enforceTimeLimit="false"
+ *          ignoreDeprecatedCodeUnitsFromCodeCoverage="false"
  *          timeoutForSmallTests="1"
  *          timeoutForMediumTests="10"
  *          timeoutForLargeTests="60"
@@ -114,7 +125,6 @@
  *     <log type="coverage-crap4j" target="/tmp/crap.xml" threshold="30"/>
  *     <log type="json" target="/tmp/logfile.json"/>
  *     <log type="plain" target="/tmp/logfile.txt"/>
- *     <log type="tap" target="/tmp/logfile.tap"/>
  *     <log type="teamcity" target="/tmp/logfile.txt"/>
  *     <log type="junit" target="/tmp/logfile.xml"/>
  *     <log type="testdox-html" target="/tmp/testdox.html"/>
@@ -137,11 +147,11 @@
  *   </php>
  * </phpunit>
  * </code>
- *
- * @since Class available since Release 3.2.0
  */
-class PHPUnit_Util_Configuration
+class Configuration
 {
+    const TEST_SUITE_FILTER_SEPARATOR = ',';
+
     private static $instances = [];
 
     protected $document;
@@ -156,13 +166,10 @@ class PHPUnit_Util_Configuration
     protected function __construct($filename)
     {
         $this->filename = $filename;
-        $this->document = PHPUnit_Util_XML::loadFile($filename, false, true, true);
+        $this->document = Xml::loadFile($filename, false, true, true);
         $this->xpath    = new DOMXPath($this->document);
     }
 
-    /**
-     * @since Method available since Release 3.4.0
-     */
     final private function __clone()
     {
     }
@@ -172,17 +179,15 @@ class PHPUnit_Util_Configuration
      *
      * @param string $filename
      *
-     * @return PHPUnit_Util_Configuration
-     *
-     * @since Method available since Release 3.4.0
+     * @return Configuration
      */
     public static function getInstance($filename)
     {
-        $realpath = realpath($filename);
+        $realpath = \realpath($filename);
 
         if ($realpath === false) {
-            throw new PHPUnit_Framework_Exception(
-                sprintf(
+            throw new Exception(
+                \sprintf(
                     'Could not read "%s".',
                     $filename
                 )
@@ -200,8 +205,6 @@ class PHPUnit_Util_Configuration
      * Returns the realpath to the configuration file.
      *
      * @return string
-     *
-     * @since Method available since Release 3.6.0
      */
     public function getFilename()
     {
@@ -212,17 +215,19 @@ class PHPUnit_Util_Configuration
      * Returns the configuration for SUT filtering.
      *
      * @return array
-     *
-     * @since Method available since Release 3.2.1
      */
     public function getFilterConfiguration()
     {
         $addUncoveredFilesFromWhitelist     = true;
         $processUncoveredFilesFromWhitelist = false;
+        $includeDirectory                   = [];
+        $includeFile                        = [];
+        $excludeDirectory                   = [];
+        $excludeFile                        = [];
 
         $tmp = $this->xpath->query('filter/whitelist');
 
-        if ($tmp->length == 1) {
+        if ($tmp->length === 1) {
             if ($tmp->item(0)->hasAttribute('addUncoveredFilesFromWhitelist')) {
                 $addUncoveredFilesFromWhitelist = $this->getBoolean(
                     (string) $tmp->item(0)->getAttribute(
@@ -240,29 +245,37 @@ class PHPUnit_Util_Configuration
                     false
                 );
             }
+
+            $includeDirectory = $this->readFilterDirectories(
+                'filter/whitelist/directory'
+            );
+
+            $includeFile = $this->readFilterFiles(
+                'filter/whitelist/file'
+            );
+
+            $excludeDirectory = $this->readFilterDirectories(
+                'filter/whitelist/exclude/directory'
+            );
+
+            $excludeFile = $this->readFilterFiles(
+                'filter/whitelist/exclude/file'
+            );
         }
 
         return [
-          'whitelist' => [
-            'addUncoveredFilesFromWhitelist'     => $addUncoveredFilesFromWhitelist,
-            'processUncoveredFilesFromWhitelist' => $processUncoveredFilesFromWhitelist,
-            'include'                            => [
-              'directory' => $this->readFilterDirectories(
-                  'filter/whitelist/directory'
-              ),
-              'file' => $this->readFilterFiles(
-                  'filter/whitelist/file'
-              )
-            ],
-            'exclude' => [
-              'directory' => $this->readFilterDirectories(
-                  'filter/whitelist/exclude/directory'
-              ),
-              'file' => $this->readFilterFiles(
-                  'filter/whitelist/exclude/file'
-              )
+            'whitelist' => [
+                'addUncoveredFilesFromWhitelist'     => $addUncoveredFilesFromWhitelist,
+                'processUncoveredFilesFromWhitelist' => $processUncoveredFilesFromWhitelist,
+                'include'                            => [
+                    'directory' => $includeDirectory,
+                    'file'      => $includeFile
+                ],
+                'exclude' => [
+                    'directory' => $excludeDirectory,
+                    'file'      => $excludeFile
+                ]
             ]
-          ]
         ];
     }
 
@@ -270,8 +283,6 @@ class PHPUnit_Util_Configuration
      * Returns the configuration for groups.
      *
      * @return array
-     *
-     * @since Method available since Release 3.2.1
      */
     public function getGroupConfiguration()
     {
@@ -282,8 +293,6 @@ class PHPUnit_Util_Configuration
      * Returns the configuration for testdox groups.
      *
      * @return array
-     *
-     * @since Method available since Release 5.4.0
      */
     public function getTestdoxGroupConfiguration()
     {
@@ -317,8 +326,6 @@ class PHPUnit_Util_Configuration
      * Returns the configuration for listeners.
      *
      * @return array
-     *
-     * @since Method available since Release 3.4.0
      */
     public function getListenerConfiguration()
     {
@@ -340,11 +347,10 @@ class PHPUnit_Util_Configuration
                 if ($node instanceof DOMElement && $node->tagName == 'arguments') {
                     foreach ($node->childNodes as $argument) {
                         if ($argument instanceof DOMElement) {
-                            if ($argument->tagName == 'file' ||
-                            $argument->tagName == 'directory') {
+                            if ($argument->tagName == 'file' || $argument->tagName == 'directory') {
                                 $arguments[] = $this->toAbsolutePath((string) $argument->textContent);
                             } else {
-                                $arguments[] = PHPUnit_Util_XML::xmlToVariable($argument);
+                                $arguments[] = Xml::xmlToVariable($argument);
                             }
                         }
                     }
@@ -352,9 +358,9 @@ class PHPUnit_Util_Configuration
             }
 
             $result[] = [
-              'class'     => $class,
-              'file'      => $file,
-              'arguments' => $arguments
+                'class'     => $class,
+                'file'      => $file,
+                'arguments' => $arguments
             ];
         }
 
@@ -426,27 +432,26 @@ class PHPUnit_Util_Configuration
      * Returns the PHP configuration.
      *
      * @return array
-     *
-     * @since Method available since Release 3.2.1
      */
     public function getPHPConfiguration()
     {
         $result = [
-          'include_path' => [],
-          'ini'          => [],
-          'const'        => [],
-          'var'          => [],
-          'env'          => [],
-          'post'         => [],
-          'get'          => [],
-          'cookie'       => [],
-          'server'       => [],
-          'files'        => [],
-          'request'      => []
+            'include_path' => [],
+            'ini'          => [],
+            'const'        => [],
+            'var'          => [],
+            'env'          => [],
+            'post'         => [],
+            'get'          => [],
+            'cookie'       => [],
+            'server'       => [],
+            'files'        => [],
+            'request'      => []
         ];
 
         foreach ($this->xpath->query('php/includePath') as $includePath) {
             $path = (string) $includePath->textContent;
+
             if ($path) {
                 $result['include_path'][] = $this->toAbsolutePath($path);
             }
@@ -456,22 +461,38 @@ class PHPUnit_Util_Configuration
             $name  = (string) $ini->getAttribute('name');
             $value = (string) $ini->getAttribute('value');
 
-            $result['ini'][$name] = $value;
+            $result['ini'][$name]['value'] = $value;
         }
 
         foreach ($this->xpath->query('php/const') as $const) {
             $name  = (string) $const->getAttribute('name');
             $value = (string) $const->getAttribute('value');
 
-            $result['const'][$name] = $this->getBoolean($value, $value);
+            $result['const'][$name]['value'] = $this->getBoolean($value, $value);
         }
 
         foreach (['var', 'env', 'post', 'get', 'cookie', 'server', 'files', 'request'] as $array) {
             foreach ($this->xpath->query('php/' . $array) as $var) {
-                $name  = (string) $var->getAttribute('name');
-                $value = (string) $var->getAttribute('value');
+                $name     = (string) $var->getAttribute('name');
+                $value    = (string) $var->getAttribute('value');
+                $verbatim = false;
+                $force    = false;
 
-                $result[$array][$name] = $this->getBoolean($value, $value);
+                if ($var->hasAttribute('verbatim')) {
+                    $verbatim                          = $this->getBoolean($var->getAttribute('verbatim'), false);
+                    $result[$array][$name]['verbatim'] = $verbatim;
+                }
+
+                if ($var->hasAttribute('force')) {
+                    $force                          = $this->getBoolean($var->getAttribute('force'), false);
+                    $result[$array][$name]['force'] = $force;
+                }
+
+                if (!$verbatim) {
+                    $value = $this->getBoolean($value, $value);
+                }
+
+                $result[$array][$name]['value'] = $value;
             }
         }
 
@@ -480,33 +501,35 @@ class PHPUnit_Util_Configuration
 
     /**
      * Handles the PHP configuration.
-     *
-     * @since Method available since Release 3.2.20
      */
     public function handlePHPConfiguration()
     {
         $configuration = $this->getPHPConfiguration();
 
-        if (! empty($configuration['include_path'])) {
-            ini_set(
+        if (!empty($configuration['include_path'])) {
+            \ini_set(
                 'include_path',
-                implode(PATH_SEPARATOR, $configuration['include_path']) .
+                \implode(PATH_SEPARATOR, $configuration['include_path']) .
                 PATH_SEPARATOR .
-                ini_get('include_path')
+                \ini_get('include_path')
             );
         }
 
-        foreach ($configuration['ini'] as $name => $value) {
-            if (defined($value)) {
-                $value = constant($value);
+        foreach ($configuration['ini'] as $name => $data) {
+            $value = $data['value'];
+
+            if (\defined($value)) {
+                $value = (string) \constant($value);
             }
 
-            ini_set($name, $value);
+            \ini_set($name, $value);
         }
 
-        foreach ($configuration['const'] as $name => $value) {
-            if (!defined($name)) {
-                define($name, $value);
+        foreach ($configuration['const'] as $name => $data) {
+            $value = $data['value'];
+
+            if (!\defined($name)) {
+                \define($name, $value);
             }
         }
 
@@ -515,29 +538,40 @@ class PHPUnit_Util_Configuration
             switch ($array) {
                 case 'var':
                     $target = &$GLOBALS;
+
                     break;
 
                 case 'server':
                     $target = &$_SERVER;
+
                     break;
 
                 default:
-                    $target = &$GLOBALS['_' . strtoupper($array)];
+                    $target = &$GLOBALS['_' . \strtoupper($array)];
+
                     break;
             }
 
-            foreach ($configuration[$array] as $name => $value) {
-                $target[$name] = $value;
+            foreach ($configuration[$array] as $name => $data) {
+                $target[$name] = $data['value'];
             }
         }
 
-        foreach ($configuration['env'] as $name => $value) {
-            if (false === getenv($name)) {
-                putenv("{$name}={$value}");
+        foreach ($configuration['env'] as $name => $data) {
+            $value = $data['value'];
+            $force = isset($data['force']) ? $data['force'] : false;
+
+            if ($force || false === \getenv($name)) {
+                \putenv("{$name}={$value}");
             }
+
             if (!isset($_ENV[$name])) {
                 $_ENV[$name] = $value;
             }
+
+            if (true === $force) {
+                $_ENV[$name] = $value;
+            }
         }
     }
 
@@ -545,8 +579,6 @@ class PHPUnit_Util_Configuration
      * Returns the PHPUnit configuration.
      *
      * @return array
-     *
-     * @since Method available since Release 3.2.14
      */
     public function getPHPUnitConfiguration()
     {
@@ -574,9 +606,9 @@ class PHPUnit_Util_Configuration
             /* only allow boolean for compatibility with previous versions
               'always' only allowed from command line */
             if ($this->getBoolean($root->getAttribute('colors'), false)) {
-                $result['colors'] = PHPUnit_TextUI_ResultPrinter::COLOR_AUTO;
+                $result['colors'] = ResultPrinter::COLOR_AUTO;
             } else {
-                $result['colors'] = PHPUnit_TextUI_ResultPrinter::COLOR_NEVER;
+                $result['colors'] = ResultPrinter::COLOR_NEVER;
             }
         }
 
@@ -593,7 +625,7 @@ class PHPUnit_Util_Configuration
         if ($root->hasAttribute('backupGlobals')) {
             $result['backupGlobals'] = $this->getBoolean(
                 (string) $root->getAttribute('backupGlobals'),
-                true
+                false
             );
         }
 
@@ -610,6 +642,13 @@ class PHPUnit_Util_Configuration
             );
         }
 
+        if ($root->hasAttribute('convertDeprecationsToExceptions')) {
+            $result['convertDeprecationsToExceptions'] = $this->getBoolean(
+                (string) $root->getAttribute('convertDeprecationsToExceptions'),
+                true
+            );
+        }
+
         if ($root->hasAttribute('convertErrorsToExceptions')) {
             $result['convertErrorsToExceptions'] = $this->getBoolean(
                 (string) $root->getAttribute('convertErrorsToExceptions'),
@@ -714,6 +753,12 @@ class PHPUnit_Util_Configuration
             );
         }
 
+        if ($root->hasAttribute('defaultTestSuite')) {
+            $result['defaultTestSuite'] = (string) $root->getAttribute(
+                'defaultTestSuite'
+            );
+        }
+
         if ($root->getAttribute('testSuiteLoaderFile')) {
             $result['testSuiteLoaderFile'] = $this->toAbsolutePath(
                 (string) $root->getAttribute('testSuiteLoaderFile')
@@ -756,7 +801,7 @@ class PHPUnit_Util_Configuration
         if ($root->hasAttribute('beStrictAboutTestsThatDoNotTestAnything')) {
             $result['reportUselessTests'] = $this->getBoolean(
                 (string) $root->getAttribute('beStrictAboutTestsThatDoNotTestAnything'),
-                false
+                true
             );
         }
 
@@ -772,13 +817,6 @@ class PHPUnit_Util_Configuration
                 (string) $root->getAttribute('beStrictAboutCoversAnnotation'),
                 false
             );
-        } elseif ($root->hasAttribute('checkForUnintentionallyCoveredCode')) {
-            $result['strictCoverage'] = $this->getBoolean(
-                (string) $root->getAttribute('checkForUnintentionallyCoveredCode'),
-                false
-            );
-
-            $result['deprecatedCheckForUnintentionallyCoveredCodeSettingUsed'] = true;
         }
 
         if ($root->hasAttribute('enforceTimeLimit')) {
@@ -788,6 +826,13 @@ class PHPUnit_Util_Configuration
             );
         }
 
+        if ($root->hasAttribute('ignoreDeprecatedCodeUnitsFromCodeCoverage')) {
+            $result['ignoreDeprecatedCodeUnitsFromCodeCoverage'] = $this->getBoolean(
+                (string) $root->getAttribute('ignoreDeprecatedCodeUnitsFromCodeCoverage'),
+                false
+            );
+        }
+
         if ($root->hasAttribute('timeoutForSmallTests')) {
             $result['timeoutForSmallTests'] = $this->getInteger(
                 (string) $root->getAttribute('timeoutForSmallTests'),
@@ -830,15 +875,23 @@ class PHPUnit_Util_Configuration
             );
         }
 
+        if ($root->hasAttribute('extensionsDirectory')) {
+            $result['extensionsDirectory'] = $this->toAbsolutePath(
+                (string) $root->getAttribute(
+                    'extensionsDirectory'
+                )
+            );
+        }
+
         return $result;
     }
 
     /**
      * Returns the test suite configuration.
      *
-     * @return PHPUnit_Framework_TestSuite
+     * @param string|null $testSuiteFilter
      *
-     * @since Method available since Release 3.2.1
+     * @return TestSuite
      */
     public function getTestSuiteConfiguration($testSuiteFilter = null)
     {
@@ -852,34 +905,48 @@ class PHPUnit_Util_Configuration
             return $this->getTestSuite($testSuiteNodes->item(0), $testSuiteFilter);
         }
 
-        if ($testSuiteNodes->length > 1) {
-            $suite = new PHPUnit_Framework_TestSuite;
+        //if ($testSuiteNodes->length > 1) { there cannot be a negative number of Nodes
+        $suite = new TestSuite;
 
-            foreach ($testSuiteNodes as $testSuiteNode) {
-                $suite->addTestSuite(
-                    $this->getTestSuite($testSuiteNode, $testSuiteFilter)
-                );
-            }
-
-            return $suite;
+        foreach ($testSuiteNodes as $testSuiteNode) {
+            $suite->addTestSuite(
+                $this->getTestSuite($testSuiteNode, $testSuiteFilter)
+            );
         }
+
+        return $suite;
     }
 
     /**
-     * @param DOMElement $testSuiteNode
+     * Returns the test suite names from the configuration.
      *
-     * @return PHPUnit_Framework_TestSuite
+     * @return array
+     */
+    public function getTestSuiteNames()
+    {
+        $names = [];
+        $nodes = $this->xpath->query('*/testsuite');
+        foreach ($nodes as $node) {
+            $names[] = $node->getAttribute('name');
+        }
+
+        return $names;
+    }
+
+    /**
+     * @param DOMElement  $testSuiteNode
+     * @param string|null $testSuiteFilter
      *
-     * @since Method available since Release 3.4.0
+     * @return TestSuite
      */
     protected function getTestSuite(DOMElement $testSuiteNode, $testSuiteFilter = null)
     {
         if ($testSuiteNode->hasAttribute('name')) {
-            $suite = new PHPUnit_Framework_TestSuite(
+            $suite = new TestSuite(
                 (string) $testSuiteNode->getAttribute('name')
             );
         } else {
-            $suite = new PHPUnit_Framework_TestSuite;
+            $suite = new TestSuite;
         }
 
         $exclude = [];
@@ -892,9 +959,10 @@ class PHPUnit_Util_Configuration
         }
 
         $fileIteratorFacade = new File_Iterator_Facade;
+        $testSuiteFilter    = $testSuiteFilter ? \explode(self::TEST_SUITE_FILTER_SEPARATOR, $testSuiteFilter) : [];
 
         foreach ($testSuiteNode->getElementsByTagName('directory') as $directoryNode) {
-            if ($testSuiteFilter && $directoryNode->parentNode->getAttribute('name') != $testSuiteFilter) {
+            if (!empty($testSuiteFilter) && !\in_array($directoryNode->parentNode->getAttribute('name'), $testSuiteFilter)) {
                 continue;
             }
 
@@ -916,7 +984,7 @@ class PHPUnit_Util_Configuration
                 $phpVersionOperator = '>=';
             }
 
-            if (!version_compare(PHP_VERSION, $phpVersion, $phpVersionOperator)) {
+            if (!\version_compare(PHP_VERSION, $phpVersion, $phpVersionOperator)) {
                 continue;
             }
 
@@ -942,7 +1010,7 @@ class PHPUnit_Util_Configuration
         }
 
         foreach ($testSuiteNode->getElementsByTagName('file') as $fileNode) {
-            if ($testSuiteFilter && $fileNode->parentNode->getAttribute('name') != $testSuiteFilter) {
+            if (!empty($testSuiteFilter) && !\in_array($fileNode->parentNode->getAttribute('name'), $testSuiteFilter)) {
                 continue;
             }
 
@@ -975,7 +1043,7 @@ class PHPUnit_Util_Configuration
                 $phpVersionOperator = '>=';
             }
 
-            if (!version_compare(PHP_VERSION, $phpVersion, $phpVersionOperator)) {
+            if (!\version_compare(PHP_VERSION, $phpVersion, $phpVersionOperator)) {
                 continue;
             }
 
@@ -986,18 +1054,22 @@ class PHPUnit_Util_Configuration
     }
 
     /**
-     * @param string $value
-     * @param bool   $default
+     * if $value is 'false' or 'true', this returns the value that $value represents.
+     * Otherwise, returns $default, which may be a string in rare cases.
+     * See PHPUnit\Util\ConfigurationTest::testPHPConfigurationIsReadCorrectly
      *
-     * @return bool
+     * @param string      $value
+     * @param string|bool $default
      *
-     * @since Method available since Release 3.2.3
+     * @return string|bool
      */
     protected function getBoolean($value, $default)
     {
-        if (strtolower($value) == 'false') {
+        if (\strtolower($value) == 'false') {
             return false;
-        } elseif (strtolower($value) == 'true') {
+        }
+
+        if (\strtolower($value) == 'true') {
             return true;
         }
 
@@ -1006,15 +1078,13 @@ class PHPUnit_Util_Configuration
 
     /**
      * @param string $value
-     * @param bool   $default
+     * @param int    $default
      *
-     * @return bool
-     *
-     * @since Method available since Release 3.6.0
+     * @return int
      */
     protected function getInteger($value, $default)
     {
-        if (is_numeric($value)) {
+        if (\is_numeric($value)) {
             return (int) $value;
         }
 
@@ -1025,8 +1095,6 @@ class PHPUnit_Util_Configuration
      * @param string $query
      *
      * @return array
-     *
-     * @since Method available since Release 3.2.3
      */
     protected function readFilterDirectories($query)
     {
@@ -1058,10 +1126,10 @@ class PHPUnit_Util_Configuration
             }
 
             $directories[] = [
-              'path'   => $this->toAbsolutePath($directoryPath),
-              'prefix' => $prefix,
-              'suffix' => $suffix,
-              'group'  => $group
+                'path'   => $this->toAbsolutePath($directoryPath),
+                'prefix' => $prefix,
+                'suffix' => $suffix,
+                'group'  => $group
             ];
         }
 
@@ -1072,8 +1140,6 @@ class PHPUnit_Util_Configuration
      * @param string $query
      *
      * @return array
-     *
-     * @since Method available since Release 3.2.3
      */
     protected function readFilterFiles($query)
     {
@@ -1095,12 +1161,10 @@ class PHPUnit_Util_Configuration
      * @param bool   $useIncludePath
      *
      * @return string
-     *
-     * @since Method available since Release 3.5.0
      */
     protected function toAbsolutePath($path, $useIncludePath = false)
     {
-        $path = trim($path);
+        $path = \trim($path);
 
         if ($path[0] === '/') {
             return $path;
@@ -1114,21 +1178,20 @@ class PHPUnit_Util_Configuration
         //  - C:\windows
         //  - C:/windows
         //  - c:/windows
-        if (defined('PHP_WINDOWS_VERSION_BUILD') &&
-            ($path[0] === '\\' ||
-            (strlen($path) >= 3 && preg_match('#^[A-Z]\:[/\\\]#i', substr($path, 0, 3))))) {
+        if (\defined('PHP_WINDOWS_VERSION_BUILD') &&
+            ($path[0] === '\\' || (\strlen($path) >= 3 && \preg_match('#^[A-Z]\:[/\\\]#i', \substr($path, 0, 3))))) {
             return $path;
         }
 
         // Stream
-        if (strpos($path, '://') !== false) {
+        if (\strpos($path, '://') !== false) {
             return $path;
         }
 
-        $file = dirname($this->filename) . DIRECTORY_SEPARATOR . $path;
+        $file = \dirname($this->filename) . DIRECTORY_SEPARATOR . $path;
 
-        if ($useIncludePath && !file_exists($file)) {
-            $includePathFile = stream_resolve_include_path($path);
+        if ($useIncludePath && !\file_exists($file)) {
+            $includePathFile = \stream_resolve_include_path($path);
 
             if ($includePathFile) {
                 $file = $includePathFile;
