@@ -7,13 +7,14 @@
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
+namespace PHPUnit\Util;
+
+use PHPUnit\Framework\Exception;
 
 /**
  * Utility class that can print to STDOUT or write to a file.
- *
- * @since Class available since Release 2.0.0
  */
-class PHPUnit_Util_Printer
+class Printer
 {
     /**
      * If true, flush output after every write.
@@ -32,37 +33,31 @@ class PHPUnit_Util_Printer
      */
     protected $outTarget;
 
-    /**
-     * @var bool
-     */
-    protected $printsHTML = false;
-
     /**
      * Constructor.
      *
      * @param mixed $out
      *
-     * @throws PHPUnit_Framework_Exception
+     * @throws Exception
      */
     public function __construct($out = null)
     {
         if ($out !== null) {
-            if (is_string($out)) {
-                if (strpos($out, 'socket://') === 0) {
-                    $out = explode(':', str_replace('socket://', '', $out));
+            if (\is_string($out)) {
+                if (\strpos($out, 'socket://') === 0) {
+                    $out = \explode(':', \str_replace('socket://', '', $out));
 
-                    if (sizeof($out) != 2) {
-                        throw new PHPUnit_Framework_Exception;
+                    if (\count($out) != 2) {
+                        throw new Exception;
                     }
 
-                    $this->out = fsockopen($out[0], $out[1]);
+                    $this->out = \fsockopen($out[0], $out[1]);
                 } else {
-                    if (strpos($out, 'php://') === false &&
-                        !is_dir(dirname($out))) {
-                        mkdir(dirname($out), 0777, true);
+                    if (\strpos($out, 'php://') === false && !\is_dir(\dirname($out))) {
+                        \mkdir(\dirname($out), 0777, true);
                     }
 
-                    $this->out = fopen($out, 'wt');
+                    $this->out = \fopen($out, 'wt');
                 }
 
                 $this->outTarget = $out;
@@ -73,27 +68,12 @@ class PHPUnit_Util_Printer
     }
 
     /**
-     * Flush buffer, optionally tidy up HTML, and close output if it's not to a php stream
+     * Flush buffer and close output if it's not to a PHP stream
      */
     public function flush()
     {
-        if ($this->out && strncmp($this->outTarget, 'php://', 6) !== 0) {
-            fclose($this->out);
-        }
-
-        if ($this->printsHTML === true &&
-            $this->outTarget !== null &&
-            strpos($this->outTarget, 'php://') !== 0 &&
-            strpos($this->outTarget, 'socket://') !== 0 &&
-            extension_loaded('tidy')) {
-            file_put_contents(
-                $this->outTarget,
-                tidy_repair_file(
-                    $this->outTarget,
-                    ['indent' => true, 'wrap' => 0],
-                    'utf8'
-                )
-            );
+        if ($this->out && \strncmp($this->outTarget, 'php://', 6) !== 0) {
+            \fclose($this->out);
         }
     }
 
@@ -103,15 +83,13 @@ class PHPUnit_Util_Printer
      * Do not confuse this function with the flush() function of this class,
      * since the flush() function may close the file being written to, rendering
      * the current object no longer usable.
-     *
-     * @since  Method available since Release 3.3.0
      */
     public function incrementalFlush()
     {
         if ($this->out) {
-            fflush($this->out);
+            \fflush($this->out);
         } else {
-            flush();
+            \flush();
         }
     }
 
@@ -121,14 +99,14 @@ class PHPUnit_Util_Printer
     public function write($buffer)
     {
         if ($this->out) {
-            fwrite($this->out, $buffer);
+            \fwrite($this->out, $buffer);
 
             if ($this->autoFlush) {
                 $this->incrementalFlush();
             }
         } else {
-            if (PHP_SAPI != 'cli') {
-                $buffer = htmlspecialchars($buffer);
+            if (PHP_SAPI != 'cli' && PHP_SAPI != 'phpdbg') {
+                $buffer = \htmlspecialchars($buffer, ENT_SUBSTITUTE);
             }
 
             print $buffer;
@@ -143,8 +121,6 @@ class PHPUnit_Util_Printer
      * Check auto-flush mode.
      *
      * @return bool
-     *
-     * @since  Method available since Release 3.3.0
      */
     public function getAutoFlush()
     {
@@ -158,15 +134,13 @@ class PHPUnit_Util_Printer
      * not be confused with the different effects of this class' flush() method.
      *
      * @param bool $autoFlush
-     *
-     * @since  Method available since Release 3.3.0
      */
     public function setAutoFlush($autoFlush)
     {
-        if (is_bool($autoFlush)) {
+        if (\is_bool($autoFlush)) {
             $this->autoFlush = $autoFlush;
         } else {
-            throw PHPUnit_Util_InvalidArgumentHelper::factory(1, 'boolean');
+            throw InvalidArgumentHelper::factory(1, 'boolean');
         }
     }
 }
