@@ -8,12 +8,12 @@
  * file that was distributed with this source code.
  */
 
+namespace PHPUnit\Util\TestDox;
+
 /**
  * Prettifies class and method names for use in TestDox documentation.
- *
- * @since Class available since Release 2.1.0
  */
-class PHPUnit_Util_TestDox_NamePrettifier
+class NamePrettifier
 {
     /**
      * @var string
@@ -42,17 +42,17 @@ class PHPUnit_Util_TestDox_NamePrettifier
         $title = $name;
 
         if ($this->suffix !== null &&
-            $this->suffix == substr($name, -1 * strlen($this->suffix))) {
-            $title = substr($title, 0, strripos($title, $this->suffix));
+            $this->suffix == \substr($name, -1 * \strlen($this->suffix))) {
+            $title = \substr($title, 0, \strripos($title, $this->suffix));
         }
 
         if ($this->prefix !== null &&
-            $this->prefix == substr($name, 0, strlen($this->prefix))) {
-            $title = substr($title, strlen($this->prefix));
+            $this->prefix == \substr($name, 0, \strlen($this->prefix))) {
+            $title = \substr($title, \strlen($this->prefix));
         }
 
-        if (substr($title, 0, 1) == '\\') {
-            $title = substr($title, 1);
+        if (\substr($title, 0, 1) == '\\') {
+            $title = \substr($title, 1);
         }
 
         return $title;
@@ -69,43 +69,43 @@ class PHPUnit_Util_TestDox_NamePrettifier
     {
         $buffer = '';
 
-        if (!is_string($name) || strlen($name) == 0) {
+        if (!\is_string($name) || \strlen($name) == 0) {
             return $buffer;
         }
 
-        $string = preg_replace('#\d+$#', '', $name, -1, $count);
+        $string = \preg_replace('#\d+$#', '', $name, -1, $count);
 
-        if (in_array($string, $this->strings)) {
+        if (\in_array($string, $this->strings)) {
             $name = $string;
         } elseif ($count == 0) {
             $this->strings[] = $string;
         }
 
-        if (strpos($name, '_') !== false) {
-            return str_replace('_', ' ', $name);
+        if (\substr($name, 0, 4) == 'test') {
+            $name = \substr($name, 4);
         }
 
-        $max = strlen($name);
-
-        if (substr($name, 0, 4) == 'test') {
-            $offset = 4;
-        } else {
-            $offset  = 0;
-            $name[0] = strtoupper($name[0]);
+        if (\strlen($name) == 0) {
+            return $buffer;
         }
 
+        $name[0] = \strtoupper($name[0]);
+
+        if (\strpos($name, '_') !== false) {
+            return \trim(\str_replace('_', ' ', $name));
+        }
+
+        $max        = \strlen($name);
         $wasNumeric = false;
 
-        for ($i = $offset; $i < $max; $i++) {
-            if ($i > $offset &&
-                ord($name[$i]) >= 65 &&
-                ord($name[$i]) <= 90) {
-                $buffer .= ' ' . strtolower($name[$i]);
+        for ($i = 0; $i < $max; $i++) {
+            if ($i > 0 && \ord($name[$i]) >= 65 && \ord($name[$i]) <= 90) {
+                $buffer .= ' ' . \strtolower($name[$i]);
             } else {
-                $isNumeric = is_numeric($name[$i]);
+                $isNumeric = \is_numeric($name[$i]);
 
                 if (!$wasNumeric && $isNumeric) {
-                    $buffer    .= ' ';
+                    $buffer .= ' ';
                     $wasNumeric = true;
                 }
 
