@@ -1,9 +1,11 @@
 <?php
+use PHPUnit\Framework\TestCase;
+
 /**
  * @runTestsInSeparateProcesses
  * @preserveGlobalState enabled
  */
-class Issue1335Test extends PHPUnit_Framework_TestCase
+class Issue1335Test extends TestCase
 {
     public function testGlobalString()
     {
@@ -27,12 +29,12 @@ class Issue1335Test extends PHPUnit_Framework_TestCase
 
     public function testGlobalBoolTrue()
     {
-        $this->assertEquals(true, $GLOBALS['globalBoolTrue']);
+        $this->assertTrue($GLOBALS['globalBoolTrue']);
     }
 
     public function testGlobalBoolFalse()
     {
-        $this->assertEquals(false, $GLOBALS['globalBoolFalse']);
+        $this->assertFalse($GLOBALS['globalBoolFalse']);
     }
 
     public function testGlobalNull()
