@@ -1,5 +1,7 @@
 <?php
-class Issue1570Test extends PHPUnit_Framework_TestCase
+use PHPUnit\Framework\TestCase;
+
+class Issue1570Test extends TestCase
 {
     public function testOne()
     {
