@@ -8,126 +8,114 @@
  * file that was distributed with this source code.
  */
 
-if (!defined('TEST_FILES_PATH')) {
-    define(
-        'TEST_FILES_PATH',
-        dirname(__DIR__) . DIRECTORY_SEPARATOR .
-        '_files' . DIRECTORY_SEPARATOR
-    );
-}
+namespace PHPUnit\Util;
 
-require TEST_FILES_PATH . 'CoverageNamespacedFunctionTest.php';
-require TEST_FILES_PATH . 'NamespaceCoveredFunction.php';
+use PharIo\Version\VersionConstraint;
+use PHPUnit\Framework\CodeCoverageException;
+use PHPUnit\Framework\Exception;
+use PHPUnit\Framework\TestCase;
+use PHPUnit\Framework\Warning;
 
-/**
- * @since      Class available since Release 3.3.6
- */
-class Util_TestTest extends PHPUnit_Framework_TestCase
+class TestTest extends TestCase
 {
     /**
-     * @covers PHPUnit_Util_Test::getExpectedException
-     *
-     * @todo   Split up in separate tests
+     * @todo Split up in separate tests
      */
     public function testGetExpectedException()
     {
         $this->assertArraySubset(
-          ['class' => 'FooBarBaz', 'code' => null, 'message' => ''],
-          PHPUnit_Util_Test::getExpectedException('ExceptionTest', 'testOne')
+            ['class' => 'FooBarBaz', 'code' => null, 'message' => ''],
+            Test::getExpectedException(\ExceptionTest::class, 'testOne')
         );
 
         $this->assertArraySubset(
-          ['class' => 'Foo_Bar_Baz', 'code' => null, 'message' => ''],
-          PHPUnit_Util_Test::getExpectedException('ExceptionTest', 'testTwo')
+            ['class' => 'Foo_Bar_Baz', 'code' => null, 'message' => ''],
+            Test::getExpectedException(\ExceptionTest::class, 'testTwo')
         );
 
         $this->assertArraySubset(
-          ['class' => 'Foo\Bar\Baz', 'code' => null, 'message' => ''],
-          PHPUnit_Util_Test::getExpectedException('ExceptionTest', 'testThree')
+            ['class' => \Foo\Bar\Baz::class, 'code' => null, 'message' => ''],
+            Test::getExpectedException(\ExceptionTest::class, 'testThree')
         );
 
         $this->assertArraySubset(
-          ['class' => 'ほげ', 'code' => null, 'message' => ''],
-          PHPUnit_Util_Test::getExpectedException('ExceptionTest', 'testFour')
+            ['class' => 'ほげ', 'code' => null, 'message' => ''],
+            Test::getExpectedException(\ExceptionTest::class, 'testFour')
         );
 
         $this->assertArraySubset(
-          ['class' => 'Class', 'code' => 1234, 'message' => 'Message'],
-          PHPUnit_Util_Test::getExpectedException('ExceptionTest', 'testFive')
+            ['class' => 'Class', 'code' => 1234, 'message' => 'Message'],
+            Test::getExpectedException(\ExceptionTest::class, 'testFive')
         );
 
         $this->assertArraySubset(
-          ['class' => 'Class', 'code' => 1234, 'message' => 'Message'],
-          PHPUnit_Util_Test::getExpectedException('ExceptionTest', 'testSix')
+            ['class' => 'Class', 'code' => 1234, 'message' => 'Message'],
+            Test::getExpectedException(\ExceptionTest::class, 'testSix')
         );
 
         $this->assertArraySubset(
-          ['class' => 'Class', 'code' => 'ExceptionCode', 'message' => 'Message'],
-          PHPUnit_Util_Test::getExpectedException('ExceptionTest', 'testSeven')
+            ['class' => 'Class', 'code' => 'ExceptionCode', 'message' => 'Message'],
+            Test::getExpectedException(\ExceptionTest::class, 'testSeven')
         );
 
         $this->assertArraySubset(
-          ['class' => 'Class', 'code' => 0, 'message' => 'Message'],
-          PHPUnit_Util_Test::getExpectedException('ExceptionTest', 'testEight')
+            ['class' => 'Class', 'code' => 0, 'message' => 'Message'],
+            Test::getExpectedException(\ExceptionTest::class, 'testEight')
         );
 
         $this->assertArraySubset(
-          ['class' => 'Class', 'code' => ExceptionTest::ERROR_CODE, 'message' => ExceptionTest::ERROR_MESSAGE],
-          PHPUnit_Util_Test::getExpectedException('ExceptionTest', 'testNine')
+            ['class' => 'Class', 'code' => \ExceptionTest::ERROR_CODE, 'message' => \ExceptionTest::ERROR_MESSAGE],
+            Test::getExpectedException(\ExceptionTest::class, 'testNine')
         );
 
         $this->assertArraySubset(
-          ['class' => 'Class', 'code' => null, 'message' => ''],
-          PHPUnit_Util_Test::getExpectedException('ExceptionTest', 'testSingleLine')
+            ['class' => 'Class', 'code' => null, 'message' => ''],
+            Test::getExpectedException(\ExceptionTest::class, 'testSingleLine')
         );
 
         $this->assertArraySubset(
-          ['class' => 'Class', 'code' => My\Space\ExceptionNamespaceTest::ERROR_CODE, 'message' => My\Space\ExceptionNamespaceTest::ERROR_MESSAGE],
-          PHPUnit_Util_Test::getExpectedException('My\Space\ExceptionNamespaceTest', 'testConstants')
+            ['class' => 'Class', 'code' => \My\Space\ExceptionNamespaceTest::ERROR_CODE, 'message' => \My\Space\ExceptionNamespaceTest::ERROR_MESSAGE],
+            Test::getExpectedException(\My\Space\ExceptionNamespaceTest::class, 'testConstants')
         );
 
         // Ensure the Class::CONST expression is only evaluated when the constant really exists
         $this->assertArraySubset(
-          ['class' => 'Class', 'code' => 'ExceptionTest::UNKNOWN_CODE_CONSTANT', 'message' => 'ExceptionTest::UNKNOWN_MESSAGE_CONSTANT'],
-          PHPUnit_Util_Test::getExpectedException('ExceptionTest', 'testUnknownConstants')
+            ['class' => 'Class', 'code' => 'ExceptionTest::UNKNOWN_CODE_CONSTANT', 'message' => 'ExceptionTest::UNKNOWN_MESSAGE_CONSTANT'],
+            Test::getExpectedException(\ExceptionTest::class, 'testUnknownConstants')
         );
 
         $this->assertArraySubset(
-          ['class' => 'Class', 'code' => 'My\Space\ExceptionNamespaceTest::UNKNOWN_CODE_CONSTANT', 'message' => 'My\Space\ExceptionNamespaceTest::UNKNOWN_MESSAGE_CONSTANT'],
-          PHPUnit_Util_Test::getExpectedException('My\Space\ExceptionNamespaceTest', 'testUnknownConstants')
+            ['class' => 'Class', 'code' => 'My\Space\ExceptionNamespaceTest::UNKNOWN_CODE_CONSTANT', 'message' => 'My\Space\ExceptionNamespaceTest::UNKNOWN_MESSAGE_CONSTANT'],
+            Test::getExpectedException(\My\Space\ExceptionNamespaceTest::class, 'testUnknownConstants')
         );
     }
 
-    /**
-     * @covers PHPUnit_Util_Test::getExpectedException
-     */
     public function testGetExpectedRegExp()
     {
         $this->assertArraySubset(
-          ['message_regex' => '#regex#'],
-          PHPUnit_Util_Test::getExpectedException('ExceptionTest', 'testWithRegexMessage')
+            ['message_regex' => '#regex#'],
+            Test::getExpectedException(\ExceptionTest::class, 'testWithRegexMessage')
         );
 
         $this->assertArraySubset(
-          ['message_regex' => '#regex#'],
-          PHPUnit_Util_Test::getExpectedException('ExceptionTest', 'testWithRegexMessageFromClassConstant')
+            ['message_regex' => '#regex#'],
+            Test::getExpectedException(\ExceptionTest::class, 'testWithRegexMessageFromClassConstant')
         );
 
         $this->assertArraySubset(
-          ['message_regex' => 'ExceptionTest::UNKNOWN_MESSAGE_REGEX_CONSTANT'],
-          PHPUnit_Util_Test::getExpectedException('ExceptionTest', 'testWithUnknowRegexMessageFromClassConstant')
+            ['message_regex' => 'ExceptionTest::UNKNOWN_MESSAGE_REGEX_CONSTANT'],
+            Test::getExpectedException(\ExceptionTest::class, 'testWithUnknowRegexMessageFromClassConstant')
         );
     }
 
     /**
-     * @covers       PHPUnit_Util_Test::getRequirements
      * @dataProvider requirementsProvider
      */
     public function testGetRequirements($test, $result)
     {
         $this->assertEquals(
             $result,
-            PHPUnit_Util_Test::getRequirements('RequirementsTest', $test)
+            Test::getRequirements(\RequirementsTest::class, $test)
         );
     }
 
@@ -139,41 +127,44 @@ class Util_TestTest extends PHPUnit_Framework_TestCase
             ['testThree',  ['PHP'        => ['version' => '2.0', 'operator' => '']]],
             ['testFour',   [
                 'PHPUnit'    => ['version' => '2.0', 'operator' => ''],
-                'PHP'        => ['version' => '1.0', 'operator' => '']]
-            ],
+                'PHP'        => ['version' => '1.0', 'operator' => ''],
+            ]],
             ['testFive',   ['PHP'        => ['version' => '5.4.0RC6', 'operator' => '']]],
             ['testSix',    ['PHP'        => ['version' => '5.4.0-alpha1', 'operator' => '']]],
             ['testSeven',  ['PHP'        => ['version' => '5.4.0beta2', 'operator' => '']]],
             ['testEight',  ['PHP'        => ['version' => '5.4-dev', 'operator' => '']]],
             ['testNine',   ['functions'  => ['testFunc']]],
             ['testTen',    ['extensions' => ['testExt']]],
-            ['testEleven', ['OS'         => '/Linux/i']],
+            ['testEleven', [
+                'OS'         => 'SunOS',
+                'OSFAMILY'   => 'Solaris',
+            ]],
             [
-              'testSpace',
-              [
-                'extensions' => ['spl'],
-                'OS'         => '/.*/i'
-              ]
+                'testSpace',
+                [
+                    'extensions' => ['spl'],
+                    'OS'         => '.*',
+                ],
             ],
             [
-              'testAllPossibleRequirements',
-              [
-                'PHP'       => ['version' => '99-dev', 'operator' => ''],
-                'PHPUnit'   => ['version' => '9-dev', 'operator' => ''],
-                'OS'        => '/DOESNOTEXIST/i',
-                'functions' => [
-                  'testFuncOne',
-                  'testFuncTwo',
+                'testAllPossibleRequirements',
+                [
+                    'PHP'       => ['version' => '99-dev', 'operator' => ''],
+                    'PHPUnit'   => ['version' => '9-dev', 'operator' => ''],
+                    'OS'        => 'DOESNOTEXIST',
+                    'functions' => [
+                        'testFuncOne',
+                        'testFuncTwo',
+                    ],
+                    'extensions' => [
+                        'testExtOne',
+                        'testExtTwo',
+                        'testExtThree',
+                    ],
+                    'extension_versions' => [
+                        'testExtThree' => ['version' => '2.0', 'operator' => ''],
+                    ],
                 ],
-                'extensions' => [
-                  'testExtOne',
-                  'testExtTwo',
-                  'testExtThree',
-                ],
-                'extension_versions' => [
-                    'testExtThree' => ['version' => '2.0', 'operator' => '']
-                ]
-              ]
             ],
             ['testSpecificExtensionVersion',
                 [
@@ -318,19 +309,164 @@ class Util_TestTest extends PHPUnit_Framework_TestCase
                     'extensions'         => ['testExtOne'],
                     'extension_versions' => ['testExtOne' => ['version' => '99', 'operator' => '>=']]
                 ]
-            ],
+            ]
         ];
     }
 
     /**
-     * @covers PHPUnit_Util_Test::getRequirements
+     * @dataProvider requirementsWithVersionConstraintsProvider
      */
+    public function testGetRequirementsWithVersionConstraints($test, array $result)
+    {
+        $requirements = Test::getRequirements(\RequirementsTest::class, $test);
+        foreach ($result as $type => $expected_requirement) {
+            $this->assertArrayHasKey(
+                "{$type}_constraint",
+                $requirements
+            );
+            $this->assertArrayHasKey(
+                'constraint',
+                $requirements["{$type}_constraint"]
+            );
+            $this->assertInstanceOf(
+                VersionConstraint::class,
+                $requirements["{$type}_constraint"]['constraint']
+            );
+            $this->assertSame(
+                $expected_requirement['constraint'],
+                $requirements["{$type}_constraint"]['constraint']->asString()
+            );
+        }
+    }
+
+    public function requirementsWithVersionConstraintsProvider()
+    {
+        return [
+            [
+                'testVersionConstraintTildeMajor',
+                [
+                    'PHP' => [
+                        'constraint' => '~1.0'
+                    ],
+                    'PHPUnit' => [
+                        'constraint' => '~2.0'
+                    ]
+                ]
+            ],
+            [
+                'testVersionConstraintCaretMajor',
+                [
+                    'PHP' => [
+                        'constraint' => '^1.0'
+                    ],
+                    'PHPUnit' => [
+                        'constraint' => '^2.0'
+                    ]
+                ]
+            ],
+            [
+                'testVersionConstraintTildeMinor',
+                [
+                    'PHP' => [
+                        'constraint' => '~3.4.7'
+                    ],
+                    'PHPUnit' => [
+                        'constraint' => '~4.7.1'
+                    ]
+                ]
+            ],
+            [
+                'testVersionConstraintCaretMinor',
+                [
+                    'PHP' => [
+                        'constraint' => '^7.0.17'
+                    ],
+                    'PHPUnit' => [
+                        'constraint' => '^4.7.1'
+                    ]
+                ]
+            ],
+            [
+                'testVersionConstraintCaretOr',
+                [
+                    'PHP' => [
+                        'constraint' => '^5.6 || ^7.0'
+                    ],
+                    'PHPUnit' => [
+                        'constraint' => '^5.0 || ^6.0'
+                    ]
+                ]
+            ],
+            [
+                'testVersionConstraintTildeOr',
+                [
+                    'PHP' => [
+                        'constraint' => '~5.6.22 || ~7.0.17'
+                    ],
+                    'PHPUnit' => [
+                        'constraint' => '^5.0.5 || ^6.0.6'
+                    ]
+                ]
+            ],
+            [
+                'testVersionConstraintTildeOrCaret',
+                [
+                    'PHP' => [
+                        'constraint' => '~5.6.22 || ^7.0'
+                    ],
+                    'PHPUnit' => [
+                        'constraint' => '~5.6.22 || ^7.0'
+                    ]
+                ]
+            ],
+            [
+                'testVersionConstraintCaretOrTilde',
+                [
+                    'PHP' => [
+                        'constraint' => '^5.6 || ~7.0.17'
+                    ],
+                    'PHPUnit' => [
+                        'constraint' => '^5.6 || ~7.0.17'
+                    ]
+                ]
+            ],
+            [
+                'testVersionConstraintRegexpIgnoresWhitespace',
+                [
+                    'PHP' => [
+                        'constraint' => '~5.6.22 || ~7.0.17'
+                    ],
+                    'PHPUnit' => [
+                        'constraint' => '~5.6.22 || ~7.0.17'
+                    ]
+                ]
+            ]
+        ];
+    }
+
+    /**
+     * @dataProvider requirementsWithInvalidVersionConstraintsThrowsExceptionProvider
+     */
+    public function testGetRequirementsWithInvalidVersionConstraintsThrowsException($test)
+    {
+        $this->expectException(Warning::class);
+        Test::getRequirements(\RequirementsTest::class, $test);
+    }
+
+    public function requirementsWithInvalidVersionConstraintsThrowsExceptionProvider()
+    {
+        return [
+            ['testVersionConstraintInvalidPhpConstraint'],
+            ['testVersionConstraintInvalidPhpUnitConstraint']
+        ];
+    }
+
     public function testGetRequirementsMergesClassAndMethodDocBlocks()
     {
         $expectedAnnotations = [
             'PHP'       => ['version' => '5.4', 'operator' => ''],
             'PHPUnit'   => ['version' => '3.7', 'operator' => ''],
-            'OS'        => '/WINNT/i',
+            'OS'        => 'WINNT',
             'functions' => [
               'testFuncClass',
               'testFuncMethod',
@@ -343,19 +479,18 @@ class Util_TestTest extends PHPUnit_Framework_TestCase
 
         $this->assertEquals(
             $expectedAnnotations,
-            PHPUnit_Util_Test::getRequirements('RequirementsClassDocBlockTest', 'testMethod')
+            Test::getRequirements(\RequirementsClassDocBlockTest::class, 'testMethod')
         );
     }
 
     /**
-     * @covers       PHPUnit_Util_Test::getMissingRequirements
      * @dataProvider missingRequirementsProvider
      */
     public function testGetMissingRequirements($test, $result)
     {
         $this->assertEquals(
             $result,
-            PHPUnit_Util_Test::getMissingRequirements('RequirementsTest', $test)
+            Test::getMissingRequirements(\RequirementsTest::class, $test)
         );
     }
 
@@ -399,75 +534,131 @@ class Util_TestTest extends PHPUnit_Framework_TestCase
             ['testExtensionVersionOperatorEquals', ['Extension testExtOne = 1.0 is required.']],
             ['testExtensionVersionOperatorDoubleEquals', ['Extension testExtOne == 1.0 is required.']],
             ['testExtensionVersionOperatorNoSpace', ['Extension testExtOne >= 99 is required.']],
+            ['testVersionConstraintTildeMajor', [
+                'PHP version does not match the required constraint ~1.0.',
+                'PHPUnit version does not match the required constraint ~2.0.'
+            ]],
+            ['testVersionConstraintCaretMajor', [
+                'PHP version does not match the required constraint ^1.0.',
+                'PHPUnit version does not match the required constraint ^2.0.'
+            ]]
         ];
     }
 
     /**
-     * @coversNothing
-     *
-     * @todo   This test does not really test functionality of PHPUnit_Util_Test
+     * @todo   This test does not really test functionality of \PHPUnit\Util\Test
      */
     public function testGetProvidedDataRegEx()
     {
-        $result = preg_match(PHPUnit_Util_Test::REGEX_DATA_PROVIDER, '@dataProvider method', $matches);
+        $result = \preg_match(Test::REGEX_DATA_PROVIDER, '@dataProvider method', $matches);
         $this->assertEquals(1, $result);
         $this->assertEquals('method', $matches[1]);
 
-        $result = preg_match(PHPUnit_Util_Test::REGEX_DATA_PROVIDER, '@dataProvider class::method', $matches);
+        $result = \preg_match(Test::REGEX_DATA_PROVIDER, '@dataProvider class::method', $matches);
         $this->assertEquals(1, $result);
         $this->assertEquals('class::method', $matches[1]);
 
-        $result = preg_match(PHPUnit_Util_Test::REGEX_DATA_PROVIDER, '@dataProvider namespace\class::method', $matches);
+        $result = \preg_match(Test::REGEX_DATA_PROVIDER, '@dataProvider namespace\class::method', $matches);
         $this->assertEquals(1, $result);
         $this->assertEquals('namespace\class::method', $matches[1]);
 
-        $result = preg_match(PHPUnit_Util_Test::REGEX_DATA_PROVIDER, '@dataProvider namespace\namespace\class::method', $matches);
+        $result = \preg_match(Test::REGEX_DATA_PROVIDER, '@dataProvider namespace\namespace\class::method', $matches);
         $this->assertEquals(1, $result);
         $this->assertEquals('namespace\namespace\class::method', $matches[1]);
 
-        $result = preg_match(PHPUnit_Util_Test::REGEX_DATA_PROVIDER, '@dataProvider メソッド', $matches);
+        $result = \preg_match(Test::REGEX_DATA_PROVIDER, '@dataProvider メソッド', $matches);
         $this->assertEquals(1, $result);
         $this->assertEquals('メソッド', $matches[1]);
     }
 
     /**
-     * @covers PHPUnit_Util_Test::getDataFromTestWithAnnotation
+     * Check if all data providers are being merged.
      */
+    public function testMultipleDataProviders()
+    {
+        $dataSets = Test::getProvidedData(\MultipleDataProviderTest::class, 'testOne');
+
+        $this->assertCount(9, $dataSets);
+
+        $aCount = 0;
+        $bCount = 0;
+        $cCount = 0;
+
+        for ($i = 0; $i < 9; $i++) {
+            $aCount += $dataSets[$i][0] != null ? 1 : 0;
+            $bCount += $dataSets[$i][1] != null ? 1 : 0;
+            $cCount += $dataSets[$i][2] != null ? 1 : 0;
+        }
+
+        $this->assertEquals(3, $aCount);
+        $this->assertEquals(3, $bCount);
+        $this->assertEquals(3, $cCount);
+    }
+
+    public function testMultipleYieldIteratorDataProviders()
+    {
+        $dataSets = Test::getProvidedData(\MultipleDataProviderTest::class, 'testTwo');
+
+        $this->assertEquals(9, \count($dataSets));
+
+        $aCount = 0;
+        $bCount = 0;
+        $cCount = 0;
+
+        for ($i = 0; $i < 9; $i++) {
+            $aCount += $dataSets[$i][0] != null ? 1 : 0;
+            $bCount += $dataSets[$i][1] != null ? 1 : 0;
+            $cCount += $dataSets[$i][2] != null ? 1 : 0;
+        }
+
+        $this->assertEquals(3, $aCount);
+        $this->assertEquals(3, $bCount);
+        $this->assertEquals(3, $cCount);
+    }
+
+    public function testWithVariousIterableDataProviders()
+    {
+        $dataSets = Test::getProvidedData(\VariousIterableDataProviderTest::class, 'test');
+
+        $this->assertEquals([
+            ['A'],
+            ['B'],
+            ['C'],
+            ['D'],
+            ['E'],
+            ['F'],
+            ['G'],
+            ['H'],
+            ['I'],
+        ], $dataSets);
+    }
+
     public function testTestWithEmptyAnnotation()
     {
-        $result = PHPUnit_Util_Test::getDataFromTestWithAnnotation("/**\n * @anotherAnnotation\n */");
+        $result = Test::getDataFromTestWithAnnotation("/**\n * @anotherAnnotation\n */");
         $this->assertNull($result);
     }
 
-    /**
-     * @covers PHPUnit_Util_Test::getDataFromTestWithAnnotation
-     */
     public function testTestWithSimpleCase()
     {
-        $result = PHPUnit_Util_Test::getDataFromTestWithAnnotation('/**
+        $result = Test::getDataFromTestWithAnnotation('/**
                                                                      * @testWith [1]
                                                                      */');
         $this->assertEquals([[1]], $result);
     }
 
-    /**
-     * @covers PHPUnit_Util_Test::getDataFromTestWithAnnotation
-     */
     public function testTestWithMultiLineMultiParameterCase()
     {
-        $result = PHPUnit_Util_Test::getDataFromTestWithAnnotation('/**
+        $result = Test::getDataFromTestWithAnnotation('/**
                                                                      * @testWith [1, 2]
                                                                      * [3, 4]
                                                                      */');
         $this->assertEquals([[1, 2], [3, 4]], $result);
     }
 
-    /**
-     * @covers PHPUnit_Util_Test::getDataFromTestWithAnnotation
-     */
     public function testTestWithVariousTypes()
     {
-        $result = PHPUnit_Util_Test::getDataFromTestWithAnnotation('/**
+        $result = Test::getDataFromTestWithAnnotation('/**
             * @testWith ["ab"]
             *           [true]
             *           [null]
@@ -475,12 +666,9 @@ class Util_TestTest extends PHPUnit_Framework_TestCase
         $this->assertEquals([['ab'], [true], [null]], $result);
     }
 
-    /**
-     * @covers PHPUnit_Util_Test::getDataFromTestWithAnnotation
-     */
     public function testTestWithAnnotationAfter()
     {
-        $result = PHPUnit_Util_Test::getDataFromTestWithAnnotation('/**
+        $result = Test::getDataFromTestWithAnnotation('/**
                                                                      * @testWith [1]
                                                                      *           [2]
                                                                      * @annotation
@@ -488,12 +676,9 @@ class Util_TestTest extends PHPUnit_Framework_TestCase
         $this->assertEquals([[1], [2]], $result);
     }
 
-    /**
-     * @covers PHPUnit_Util_Test::getDataFromTestWithAnnotation
-     */
     public function testTestWithSimpleTextAfter()
     {
-        $result = PHPUnit_Util_Test::getDataFromTestWithAnnotation('/**
+        $result = Test::getDataFromTestWithAnnotation('/**
                                                                      * @testWith [1]
                                                                      *           [2]
                                                                      * blah blah
@@ -501,41 +686,43 @@ class Util_TestTest extends PHPUnit_Framework_TestCase
         $this->assertEquals([[1], [2]], $result);
     }
 
-    /**
-     * @covers PHPUnit_Util_Test::getDataFromTestWithAnnotation
-     */
     public function testTestWithCharacterEscape()
     {
-        $result = PHPUnit_Util_Test::getDataFromTestWithAnnotation('/**
+        $result = Test::getDataFromTestWithAnnotation('/**
                                                                      * @testWith ["\"", "\""]
                                                                      */');
         $this->assertEquals([['"', '"']], $result);
     }
 
-    /**
-     * @covers PHPUnit_Util_Test::getDataFromTestWithAnnotation
-     */
     public function testTestWithThrowsProperExceptionIfDatasetCannotBeParsed()
     {
-        $this->setExpectedExceptionRegExp(
-            'PHPUnit_Framework_Exception',
-            '/^The dataset for the @testWith annotation cannot be parsed.$/'
-        );
-        PHPUnit_Util_Test::getDataFromTestWithAnnotation('/**
+        $this->expectException(Exception::class);
+        $this->expectExceptionMessageRegExp('/^The dataset for the @testWith annotation cannot be parsed:/');
+
+        Test::getDataFromTestWithAnnotation('/**
                                                            * @testWith [s]
                                                            */');
     }
 
+    public function testTestWithThrowsProperExceptionIfMultiLineDatasetCannotBeParsed()
+    {
+        $this->expectException(Exception::class);
+        $this->expectExceptionMessageRegExp('/^The dataset for the @testWith annotation cannot be parsed:/');
+
+        Test::getDataFromTestWithAnnotation('/**
+                                                           * @testWith ["valid"]
+                                                           *           [invalid]
+                                                           */');
+    }
+
     /**
-     * @covers PHPUnit_Util_Test::getDependencies
-     *
-     * @todo   Not sure what this test tests (name is misleading at least)
+     * @todo Not sure what this test tests (name is misleading at least)
      */
     public function testParseAnnotation()
     {
         $this->assertEquals(
             ['Foo', 'ほげ'],
-            PHPUnit_Util_Test::getDependencies(get_class($this), 'methodForTestParseAnnotation')
+            Test::getDependencies(\get_class($this), 'methodForTestParseAnnotation')
         );
     }
 
@@ -543,20 +730,17 @@ class Util_TestTest extends PHPUnit_Framework_TestCase
      * @depends Foo
      * @depends ほげ
      *
-     * @todo    Remove fixture from test class
+     * @todo Remove fixture from test class
      */
     public function methodForTestParseAnnotation()
     {
     }
 
-    /**
-     * @covers PHPUnit_Util_Test::getDependencies
-     */
     public function testParseAnnotationThatIsOnlyOneLine()
     {
         $this->assertEquals(
             ['Bar'],
-            PHPUnit_Util_Test::getDependencies(get_class($this), 'methodForTestParseAnnotationThatIsOnlyOneLine')
+            Test::getDependencies(\get_class($this), 'methodForTestParseAnnotationThatIsOnlyOneLine')
         );
     }
 
@@ -567,14 +751,11 @@ class Util_TestTest extends PHPUnit_Framework_TestCase
     }
 
     /**
-     * @covers       PHPUnit_Util_Test::getLinesToBeCovered
-     * @covers       PHPUnit_Util_Test::getLinesToBeCoveredOrUsed
-     * @covers       PHPUnit_Util_Test::resolveElementToReflectionObjects
      * @dataProvider getLinesToBeCoveredProvider
      */
     public function testGetLinesToBeCovered($test, $lines)
     {
-        if (strpos($test, 'Namespace') === 0) {
+        if (\strpos($test, 'Namespace') === 0) {
             $expected = [
               TEST_FILES_PATH . 'NamespaceCoveredClass.php' => $lines
             ];
@@ -592,151 +773,116 @@ class Util_TestTest extends PHPUnit_Framework_TestCase
 
         $this->assertEquals(
             $expected,
-            PHPUnit_Util_Test::getLinesToBeCovered(
-                $test, 'testSomething'
+            Test::getLinesToBeCovered(
+                $test,
+                'testSomething'
             )
         );
     }
 
-    /**
-     * @covers            PHPUnit_Util_Test::getLinesToBeCovered
-     * @covers            PHPUnit_Util_Test::getLinesToBeCoveredOrUsed
-     * @covers            PHPUnit_Util_Test::resolveElementToReflectionObjects
-     * @expectedException PHPUnit_Framework_CodeCoverageException
-     */
     public function testGetLinesToBeCovered2()
     {
-        PHPUnit_Util_Test::getLinesToBeCovered(
-            'NotExistingCoveredElementTest', 'testOne'
+        $this->expectException(CodeCoverageException::class);
+
+        Test::getLinesToBeCovered(
+            'NotExistingCoveredElementTest',
+            'testOne'
         );
     }
 
-    /**
-     * @covers            PHPUnit_Util_Test::getLinesToBeCovered
-     * @covers            PHPUnit_Util_Test::getLinesToBeCoveredOrUsed
-     * @covers            PHPUnit_Util_Test::resolveElementToReflectionObjects
-     * @expectedException PHPUnit_Framework_CodeCoverageException
-     */
     public function testGetLinesToBeCovered3()
     {
-        PHPUnit_Util_Test::getLinesToBeCovered(
-            'NotExistingCoveredElementTest', 'testTwo'
+        $this->expectException(CodeCoverageException::class);
+
+        Test::getLinesToBeCovered(
+            'NotExistingCoveredElementTest',
+            'testTwo'
         );
     }
 
-    /**
-     * @covers            PHPUnit_Util_Test::getLinesToBeCovered
-     * @covers            PHPUnit_Util_Test::getLinesToBeCoveredOrUsed
-     * @covers            PHPUnit_Util_Test::resolveElementToReflectionObjects
-     * @expectedException PHPUnit_Framework_CodeCoverageException
-     */
     public function testGetLinesToBeCovered4()
     {
-        PHPUnit_Util_Test::getLinesToBeCovered(
-            'NotExistingCoveredElementTest', 'testThree'
+        $this->expectException(CodeCoverageException::class);
+
+        Test::getLinesToBeCovered(
+            'NotExistingCoveredElementTest',
+            'testThree'
         );
     }
 
-    /**
-     * @covers PHPUnit_Util_Test::getLinesToBeCovered
-     * @covers PHPUnit_Util_Test::getLinesToBeCoveredOrUsed
-     */
     public function testGetLinesToBeCoveredSkipsNonExistentMethods()
     {
         $this->assertSame(
             [],
-            PHPUnit_Util_Test::getLinesToBeCovered(
+            Test::getLinesToBeCovered(
                 'NotExistingCoveredElementTest',
                 'methodDoesNotExist'
             )
         );
     }
 
-    /**
-     * @covers            PHPUnit_Util_Test::getLinesToBeCovered
-     * @covers            PHPUnit_Util_Test::getLinesToBeCoveredOrUsed
-     * @expectedException PHPUnit_Framework_CodeCoverageException
-     */
-    public function testTwoCoversDefaultClassAnnoationsAreNotAllowed()
+    public function testTwoCoversDefaultClassAnnotationsAreNotAllowed()
     {
-        PHPUnit_Util_Test::getLinesToBeCovered(
+        $this->expectException(CodeCoverageException::class);
+
+        Test::getLinesToBeCovered(
             'CoverageTwoDefaultClassAnnotations',
             'testSomething'
         );
     }
 
-    /**
-     * @covers PHPUnit_Util_Test::getLinesToBeCovered
-     * @covers PHPUnit_Util_Test::getLinesToBeCoveredOrUsed
-     */
     public function testFunctionParenthesesAreAllowed()
     {
         $this->assertSame(
-            [TEST_FILES_PATH . 'CoveredFunction.php' => range(2, 4)],
-            PHPUnit_Util_Test::getLinesToBeCovered(
+            [TEST_FILES_PATH . 'CoveredFunction.php' => \range(2, 4)],
+            Test::getLinesToBeCovered(
                 'CoverageFunctionParenthesesTest',
                 'testSomething'
             )
         );
     }
 
-    /**
-     * @covers PHPUnit_Util_Test::getLinesToBeCovered
-     * @covers PHPUnit_Util_Test::getLinesToBeCoveredOrUsed
-     */
     public function testFunctionParenthesesAreAllowedWithWhitespace()
     {
         $this->assertSame(
-            [TEST_FILES_PATH . 'CoveredFunction.php' => range(2, 4)],
-            PHPUnit_Util_Test::getLinesToBeCovered(
+            [TEST_FILES_PATH . 'CoveredFunction.php' => \range(2, 4)],
+            Test::getLinesToBeCovered(
                 'CoverageFunctionParenthesesWhitespaceTest',
                 'testSomething'
             )
         );
     }
 
-    /**
-     * @covers PHPUnit_Util_Test::getLinesToBeCovered
-     * @covers PHPUnit_Util_Test::getLinesToBeCoveredOrUsed
-     */
     public function testMethodParenthesesAreAllowed()
     {
         $this->assertSame(
-            [TEST_FILES_PATH . 'CoveredClass.php' => range(31, 35)],
-            PHPUnit_Util_Test::getLinesToBeCovered(
+            [TEST_FILES_PATH . 'CoveredClass.php' => \range(31, 35)],
+            Test::getLinesToBeCovered(
                 'CoverageMethodParenthesesTest',
                 'testSomething'
             )
         );
     }
 
-    /**
-     * @covers PHPUnit_Util_Test::getLinesToBeCovered
-     * @covers PHPUnit_Util_Test::getLinesToBeCoveredOrUsed
-     */
     public function testMethodParenthesesAreAllowedWithWhitespace()
     {
         $this->assertSame(
-            [TEST_FILES_PATH . 'CoveredClass.php' => range(31, 35)],
-            PHPUnit_Util_Test::getLinesToBeCovered(
+            [TEST_FILES_PATH . 'CoveredClass.php' => \range(31, 35)],
+            Test::getLinesToBeCovered(
                 'CoverageMethodParenthesesWhitespaceTest',
                 'testSomething'
             )
         );
     }
 
-    /**
-     * @covers PHPUnit_Util_Test::getLinesToBeCovered
-     * @covers PHPUnit_Util_Test::getLinesToBeCoveredOrUsed
-     */
     public function testNamespacedFunctionCanBeCoveredOrUsed()
     {
         $this->assertEquals(
             [
-                TEST_FILES_PATH . 'NamespaceCoveredFunction.php' => range(4, 7)
+                TEST_FILES_PATH . 'NamespaceCoveredFunction.php' => \range(4, 7)
             ],
-            PHPUnit_Util_Test::getLinesToBeCovered(
-                'CoverageNamespacedFunctionTest',
+            Test::getLinesToBeCovered(
+                \CoverageNamespacedFunctionTest::class,
                 'testFunc'
             )
         );
@@ -751,91 +897,91 @@ class Util_TestTest extends PHPUnit_Framework_TestCase
           ],
           [
             'CoverageClassExtendedTest',
-            array_merge(range(19, 36), range(2, 17))
+            \array_merge(\range(19, 36), \range(2, 17))
           ],
           [
             'CoverageClassTest',
-            range(19, 36)
+            \range(19, 36)
           ],
           [
             'CoverageMethodTest',
-            range(31, 35)
+            \range(31, 35)
           ],
           [
             'CoverageMethodOneLineAnnotationTest',
-            range(31, 35)
+            \range(31, 35)
           ],
           [
             'CoverageNotPrivateTest',
-            array_merge(range(25, 29), range(31, 35))
+            \array_merge(\range(25, 29), \range(31, 35))
           ],
           [
             'CoverageNotProtectedTest',
-            array_merge(range(21, 23), range(31, 35))
+            \array_merge(\range(21, 23), \range(31, 35))
           ],
           [
             'CoverageNotPublicTest',
-            array_merge(range(21, 23), range(25, 29))
+            \array_merge(\range(21, 23), \range(25, 29))
           ],
           [
             'CoveragePrivateTest',
-            range(21, 23)
+            \range(21, 23)
           ],
           [
             'CoverageProtectedTest',
-            range(25, 29)
+            \range(25, 29)
           ],
           [
             'CoveragePublicTest',
-            range(31, 35)
+            \range(31, 35)
           ],
           [
             'CoverageFunctionTest',
-            range(2, 4)
+            \range(2, 4)
           ],
           [
             'NamespaceCoverageClassExtendedTest',
-            array_merge(range(21, 38), range(4, 19))
+            \array_merge(\range(21, 38), \range(4, 19))
           ],
           [
             'NamespaceCoverageClassTest',
-            range(21, 38)
+            \range(21, 38)
           ],
           [
             'NamespaceCoverageMethodTest',
-            range(33, 37)
+            \range(33, 37)
           ],
           [
             'NamespaceCoverageNotPrivateTest',
-            array_merge(range(27, 31), range(33, 37))
+            \array_merge(\range(27, 31), \range(33, 37))
           ],
           [
             'NamespaceCoverageNotProtectedTest',
-            array_merge(range(23, 25), range(33, 37))
+            \array_merge(\range(23, 25), \range(33, 37))
           ],
           [
             'NamespaceCoverageNotPublicTest',
-            array_merge(range(23, 25), range(27, 31))
+            \array_merge(\range(23, 25), \range(27, 31))
           ],
           [
             'NamespaceCoveragePrivateTest',
-            range(23, 25)
+            \range(23, 25)
           ],
           [
             'NamespaceCoverageProtectedTest',
-            range(27, 31)
+            \range(27, 31)
           ],
           [
             'NamespaceCoveragePublicTest',
-            range(33, 37)
+            \range(33, 37)
           ],
           [
             'NamespaceCoverageCoversClassTest',
-            array_merge(range(23, 25), range(27, 31), range(33, 37), range(6, 8), range(10, 13), range(15, 18))
+            \array_merge(\range(23, 25), \range(27, 31), \range(33, 37), \range(6, 8), \range(10, 13), \range(15, 18))
           ],
           [
             'NamespaceCoverageCoversClassPublicTest',
-            range(33, 37)
+            \range(33, 37)
           ],
           [
             'CoverageNothingTest',
@@ -843,4 +989,14 @@ class Util_TestTest extends PHPUnit_Framework_TestCase
           ]
         ];
     }
+
+    public function testParseTestMethodAnnotationsIncorporatesTraits()
+    {
+        $result = Test::parseTestMethodAnnotations(\ParseTestMethodAnnotationsMock::class);
+
+        $this->assertArrayHasKey('class', $result);
+        $this->assertArrayHasKey('method', $result);
+        $this->assertArrayHasKey('theClassAnnotation', $result['class']);
+        $this->assertArrayHasKey('theTraitAnnotation', $result['class']);
+    }
 }
