@@ -7,13 +7,12 @@
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
+use PHPUnit\Framework\TestCase;
 
 /**
  * Tests for the BankAccount class.
- *
- * @since      Class available since Release 2.3.0
  */
-class BankAccountTest extends PHPUnit_Framework_TestCase
+class BankAccountTest extends TestCase
 {
     protected $ba;
 
