@@ -1,5 +1,7 @@
 <?php
-class DataProviderFilterTest extends PHPUnit_Framework_TestCase
+use PHPUnit\Framework\TestCase;
+
+class DataProviderFilterTest extends TestCase
 {
     /**
      * @dataProvider truthProvider
@@ -11,12 +13,12 @@ class DataProviderFilterTest extends PHPUnit_Framework_TestCase
 
     public static function truthProvider()
     {
-        return array(
-           array(true),
-           array(true),
-           array(true),
-           array(true)
-        );
+        return [
+           [true],
+           [true],
+           [true],
+           [true]
+        ];
     }
 
     /**
@@ -29,11 +31,11 @@ class DataProviderFilterTest extends PHPUnit_Framework_TestCase
 
     public static function falseProvider()
     {
-        return array(
-          'false test'=>array(false),
-          'false test 2'=>array(false),
-          'other false test'=>array(false),
-          'other false test2'=>array(false)
-        );
+        return [
+          'false test'       => [false],
+          'false test 2'     => [false],
+          'other false test' => [false],
+          'other false test2'=> [false]
+        ];
     }
 }
