@@ -1,11 +1,13 @@
 <?php
-class ExceptionInAssertPreConditionsTest extends PHPUnit_Framework_TestCase
+use PHPUnit\Framework\TestCase;
+
+class ExceptionInAssertPreConditionsTest extends TestCase
 {
-    public $setUp = false;
-    public $assertPreConditions = false;
+    public $setUp                = false;
+    public $assertPreConditions  = false;
     public $assertPostConditions = false;
-    public $tearDown = false;
-    public $testSomething = false;
+    public $tearDown             = false;
+    public $testSomething        = false;
 
     protected function setUp()
     {
