@@ -1,13 +1,17 @@
 <?php
-class ExceptionStackTest extends PHPUnit_Framework_TestCase
+use PHPUnit\Framework\ExpectationFailedException;
+use PHPUnit\Framework\TestCase;
+
+class ExceptionStackTest extends TestCase
 {
     public function testPrintingChildException()
     {
         try {
             $this->assertEquals([1], [2], 'message');
-        } catch (PHPUnit_Framework_ExpectationFailedException $e) {
+        } catch (ExpectationFailedException $e) {
             $message = $e->getMessage() . $e->getComparisonFailure()->getDiff();
-            throw new PHPUnit_Framework_Exception("Child exception\n$message", 101, $e);
+
+            throw new PHPUnit\Framework\Exception("Child exception\n$message", 101, $e);
         }
     }
 
@@ -16,6 +20,7 @@ class ExceptionStackTest extends PHPUnit_Framework_TestCase
         $exceptionThree = new Exception('Three');
         $exceptionTwo   = new InvalidArgumentException('Two', 0, $exceptionThree);
         $exceptionOne   = new Exception('One', 0, $exceptionTwo);
+
         throw $exceptionOne;
     }
 }
