@@ -1,5 +1,7 @@
 <?php
-class TemplateMethodsTest extends PHPUnit_Framework_TestCase
+use PHPUnit\Framework\TestCase;
+
+class TemplateMethodsTest extends TestCase
 {
     public static function setUpBeforeClass()
     {
@@ -43,9 +45,9 @@ class TemplateMethodsTest extends PHPUnit_Framework_TestCase
         print __METHOD__ . "\n";
     }
 
-    protected function onNotSuccessfulTest(Exception $e)
+    protected function onNotSuccessfulTest(Exception $t)
     {
         print __METHOD__ . "\n";
-        throw $e;
+        throw $t;
     }
 }
